summary refs log tree commit diff stats
path: root/lib/pure/terminal.nim
diff options
context:
space:
mode:
Diffstat (limited to 'lib/pure/terminal.nim')
-rw-r--r--lib/pure/terminal.nim6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/pure/terminal.nim b/lib/pure/terminal.nim
index 2efdf72d5..b6d99e429 100644
--- a/lib/pure/terminal.nim
+++ b/lib/pure/terminal.nim
@@ -430,8 +430,8 @@ macro styledEcho*(m: varargs[expr]): stmt =
     case item.kind
     of nnkStrLit..nnkTripleStrLit:
       if i == m.len - 1:
-        # optimize if string literal is last, just call writeln
-        result.add(newCall(bindSym"writeln", bindSym"stdout", item))
+        # optimize if string literal is last, just call writeLine
+        result.add(newCall(bindSym"writeLine", bindSym"stdout", item))
         if reset: result.add(newCall(bindSym"resetAttributes"))
         return
       else:
@@ -470,7 +470,7 @@ when not defined(testing) and isMainModule:
   writeStyled("styled text ", {styleBright, styleBlink, styleUnderscore})
   setBackGroundColor(bgCyan, true)
   setForeGroundColor(fgBlue)
-  writeln(stdout, "ordinary text")
+  writeLine(stdout, "ordinary text")
 
   styledEcho("styled text ", {styleBright, styleBlink, styleUnderscore})